#include <check.h>

#include "../src/include/ttail.h"

ttail_t *ttail;

void teardown_ttail(void)
{
	ttail_free(ttail);
}
/*
 * Empty argument parsing test case
 */
void setup_ttail_empty(void)
{
	ttail = ttail_init(1, (char**)&"foo");
}
START_TEST (test_argparse_empty_logfilename)
{
	ck_assert_msg(ttail->logfile_name == NULL,
		"ttail_t.logfile_name should be NULL");
}
END_TEST
START_TEST (test_argparse_empty_logfile)
{
	ck_assert_msg(ttail->logfile == NULL,
		"ttail_t.logfile should be NULL");
}
END_TEST
START_TEST (test_argparse_empty_logfilesz)
{
	ck_assert_msg(ttail->logfile_sz == 0,
		"ttail_t.logfile_sz should be 0");
}
END_TEST
START_TEST (test_argparse_empty_prefix_flag)
{
	ck_assert_msg(ttail->date_prefix_flag == 0,
		"ttail_t.date_prefix_flag should be 0");
}
END_TEST
START_TEST (test_argparse_empty_fmt)
{
	ck_assert_msg(ttail->fmt == NULL,
		"ttail_t.fmt should be NULL");
}
END_TEST
START_TEST (test_argparse_empty_verbose)
{
	ck_assert_msg(ttail->verbose == 0,
		"ttail_t.verbose should be 0");
}
END_TEST

/*
 * file argument parsing
 */

START_TEST (test_init_file_non_exist)
{
	ttail_t *t;
	char *args[3] = {"foo", "-f", "__non__existing__"};

	t = ttail_init(3, args);

	ck_assert_msg(t->logfile_sz == 1,
		"ttail_t.logfile_sz should be 1");
	ck_assert_msg(strcmp(t->logfile_name[0], args[2]) == 0,
		"ttail_t.logfile_name[0] does not contain the filename");
	ck_assert_msg(t->logfile[0] == NULL,
		"ttail_t.logfile[0] should be NULL");
	
	ttail_free(t);

}
END_TEST

Suite * ttail_init_suite(void)
{
	Suite *s;
	TCase *tc_argparse_empty;
	TCase *tc_init_files;

	s = suite_create("ttail init methods tests");

	tc_argparse_empty = tcase_create("Empty arguments parsing");
	tcase_add_checked_fixture(tc_argparse_empty,
		setup_ttail_empty, teardown_ttail);
	tcase_add_test(tc_argparse_empty, test_argparse_empty_logfilename);
	tcase_add_test(tc_argparse_empty, test_argparse_empty_logfile);
	tcase_add_test(tc_argparse_empty, test_argparse_empty_logfilesz);
	tcase_add_test(tc_argparse_empty, test_argparse_empty_prefix_flag);
	tcase_add_test(tc_argparse_empty, test_argparse_empty_fmt);
	tcase_add_test(tc_argparse_empty, test_argparse_empty_verbose);

	tc_init_files = tcase_create("files options handling");
	tcase_add_test(tc_init_files, test_init_file_non_exist);

	suite_add_tcase(s, tc_init_files);
	suite_add_tcase(s, tc_argparse_empty);
	return s;
}

int main(void)
{
	int number_failed = 0;
	SRunner *sr;

	sr = srunner_create(ttail_init_suite());

	srunner_run_all(sr,CK_VERBOSE);
	number_failed = srunner_ntests_failed(sr);
	srunner_free(sr);
	return (number_failed == 0) ? EXIT_SUCCESS : EXIT_FAILURE;

}
